==> sflphone_1.2.3.orig.tar.gz: sflphone-1.2.3/kde/src/sflphonecmd.h <==
/***************************************************************************
 *   Copyright (C) 2013 by Savoir-Faire Linux                              *
 *   Author : Emmanuel Lepage Vallee <emmanuel.lepage@savoirfairelinux.com>*
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 **************************************************************************/

#ifndef SFLPHONECMD_H
#define SFLPHONECMD_H

#include <QtCore/QObject>

//KDE
class KAboutData;

//SFLPhone
class Call;

class SFLPhoneCmd : public QObject {
   Q_OBJECT

public:
   virtual ~SFLPhoneCmd(){}

   //Static mutators
   static void parseCmd(int argc, char **argv, KAboutData& about);
   static void placeCall(QString number);
   static void sendText(QString number, QString text);

private:
   //Private constructor
   explicit SFLPhoneCmd(QObject* parent=nullptr);

   static SFLPhoneCmd* getInstance();

   //Attributes
   static SFLPhoneCmd* m_spSelf;

private Q_SLOTS:
   void textMessagePickup(Call* call);
};

#endif

==> sflphone_1.3.0.orig.tar.gz: sflphone-1.3.0/kde/src/sflphonecmd.h <==
/***************************************************************************
 *   Copyright (C) 2013-2014 by Savoir-Faire Linux                         *
 *   Author : Emmanuel Lepage Vallee <emmanuel.lepage@savoirfairelinux.com>*
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 **************************************************************************/

#ifndef SFLPHONECMD_H
#define SFLPHONECMD_H

#include <QtCore/QObject>

//KDE
class KAboutData;

//SFLPhone
class Call;

class SFLPhoneCmd : public QObject {
   Q_OBJECT

public:
   virtual ~SFLPhoneCmd(){}

   //Static mutators
   static void parseCmd(int argc, char **argv, KAboutData& about);
   static void placeCall(const QString& number);
   static void sendText(const QString& number, const QString& text);

private:
   //Private constructor
   explicit SFLPhoneCmd(QObject* parent=nullptr);

   static SFLPhoneCmd* instance();

   //Attributes
   static SFLPhoneCmd* m_spSelf;

private Q_SLOTS:
   void textMessagePickup(Call* call);
};

#endif
